### DS9 Quick Look Plugin Reference Manual

###

> SAOImage DS9 is an astronomical imaging and data visualization application. Its 30 years of development has made it very stable and easy to use. Because of this it became an essential tool in all fields of astronomy (observation, simulation, instrumentation). Much more profitable but pretty unsung feature, its extensibility makes it a limitless tool to interact with astronomical (or not) data. Unfortunately it appears that this extensibility did not inspire or generate a large collaborative and well organized effort to develop important extensions that would finally, years after years, converge towards a stable/rapid/configurable multi-extension package of DS9 which would make it as essential as Photoshop for photographers.

> Because I am convince of its interest, this extension is a very naive attempt to try initiate this tendency. Besides joining the very user friendly but general DS9 interface with a series of more specific function this extension tries to gather a glimpse of all the possibilities that offers DS9 extensibility. The documentation can be found here. Please check out the youtube video. This quicklook plug-in is divided in three main extensions so that each of them fill a specific need:

> 1. Generic Function extension:
> 1. Fill some gaps of DS9 with stable generic functions: Radial/Energy profiles, stacking, fitting, region based functions
> 2. Gain some time with key functions: Automatically change display/lock/other parameters
> 3. Simplify the interaction with fits or DS9 objects such as Header or regions that can be modified/exported via DS9 GUI.
> 4. Create images data base based on header information that can then be used to create data subset verifying specific condditions
> 2. Instrumentation extension in order to assist instrumentalist during AIT and detector characterization.
> 1. Add some generic AIT functions: Throughfocus [Through-slit] visualization and analysis, centering, Radial profiles
> 2. Link more complex but general processing functions: Autocorrelation, FFT, smoothing, maskink/interpolation, noise measurements. These functions can be particularly interesting for detector charaterization or integration.
> 3. Astronomical software extension:
> 1. Link the most essential astronomical image processing softwares such as SExtractor, STIFF, SWARP, PSFex and offer them a parameter GUI
> 2. Link to an astrometric calibration code astrometry.net that perform a pattern recognition algorithm to create a WCS header
> 3. Contain a all-in-one astronomical functions package: converter, cosmological calculator, etc.

> | Important features |